from destipy.utils.http_method import HTTPMethod
from destipy.utils.requester import Requester


class Trending:
    """Trending endpoints."""

    def __init__(self, requester, logger):
        self.requester: Requester = requester
        self.logger = logger
        self.base_url = "https://www.bungie.net/Platform"

    async def GetTrendingCategories(self) -> dict:
        """Returns trending items for Bungie.net, collapsed into the first page of items per category. For pagination within a category, call GetTrendingCategory.

            Args:

            Returns:
        {
            "categories": {
                "Name": "categories",
                "Type": "array",
                "Description": "",
                "Attributes": [],
                "Array Contents": [
                    {
                        "categoryName": {
                            "Name": "categoryName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "entries": {
                            "results": {
                                "Name": "results",
                                "Type": "array",
                                "Description": "",
                                "Attributes": [],
                                "Array Contents": [
                                    {
                                        "weight": {
                                            "Name": "weight",
                                            "Type": "double",
                                            "Description": "The weighted score of this trending item.",
                                            "Attributes": []
                                        }
                                    },
                                    {
                                        "isFeatured": {
                                            "Name": "isFeatured",
                                            "Type": "boolean",
                                            "Description": "",
                                            "Attributes": []
                                        }
                                    },
                                    {
                                        "identifier": {
                                            "Name": "identifier",
                                            "Type": "string",
                                            "Description": "We don't know whether the identifier will be a string, a uint, or a long... so we're going to cast it all to a string. But either way, we need any trending item created to have a single unique identifier for its type.",
                                            "Attributes": []
                                        }
                                    },
                                    {
                                        "entityType": {
                                            "Name": "entityType",
                                            "Type": "int32",
                                            "Description": "An enum - unfortunately - dictating all of the possible kinds of trending items that you might get in your result set, in case you want to do custom rendering or call to get the details of the item.",
                                            "Attributes": []
                                        }
                                    },
                                    {
                                        "displayName": {
                                            "Name": "displayName",
                                            "Type": "string",
                                            "Description": "The localized \"display name/article title/'primary localized identifier'\" of the entity.",
                                            "Attributes": []
                                        }
                                    },
                                    {
                                        "tagline": {
                                            "Name": "tagline",
                                            "Type": "string",
                                            "Description": "If the entity has a localized tagline/subtitle/motto/whatever, that is found here.",
                                            "Attributes": []
                                        }
                                    },
                                    {
                                        "image": {
                                            "Name": "image",
                                            "Type": "string",
                                            "Description": "",
                                            "Attributes": []
                                        }
                                    },
                                    {
                                        "startDate": {
                                            "Name": "startDate",
                                            "Type": "date-time",
                                            "Description": "",
                                            "Attributes": [
                                                "Nullable"
                                            ]
                                        }
                                    },
                                    {
                                        "endDate": {
                                            "Name": "endDate",
                                            "Type": "date-time",
                                            "Description": "",
                                            "Attributes": [
                                                "Nullable"
                                            ]
                                        }
                                    },
                                    {
                                        "link": {
                                            "Name": "link",
                                            "Type": "string",
                                            "Description": "",
                                            "Attributes": []
                                        }
                                    },
                                    {
                                        "webmVideo": {
                                            "Name": "webmVideo",
                                            "Type": "string",
                                            "Description": "If this is populated, the entry has a related WebM video to show. I am 100% certain I am going to regret putting this directly on TrendingEntry, but it will work so yolo",
                                            "Attributes": []
                                        }
                                    },
                                    {
                                        "mp4Video": {
                                            "Name": "mp4Video",
                                            "Type": "string",
                                            "Description": "If this is populated, the entry has a related MP4 video to show. I am 100% certain I am going to regret putting this directly on TrendingEntry, but it will work so yolo",
                                            "Attributes": []
                                        }
                                    },
                                    {
                                        "featureImage": {
                                            "Name": "featureImage",
                                            "Type": "string",
                                            "Description": "If isFeatured, this image will be populated with whatever the featured image is. Note that this will likely be a very large image, so don't use it all the time.",
                                            "Attributes": []
                                        }
                                    },
                                    {
                                        "items": {
                                            "Name": "items",
                                            "Type": "array",
                                            "Description": "If the item is of entityType TrendingEntryType.Container, it may have items - also Trending Entries - contained within it. This is the ordered list of those to display under the Container's header.",
                                            "Attributes": []
                                        }
                                    },
                                    {
                                        "creationDate": {
                                            "Name": "creationDate",
                                            "Type": "date-time",
                                            "Description": "If the entry has a date at which it was created, this is that date.",
                                            "Attributes": [
                                                "Nullable"
                                            ]
                                        }
                                    }
                                ]
                            },
                            "totalResults": {
                                "Name": "totalResults",
                                "Type": "int32",
                                "Description": "",
                                "Attributes": []
                            },
                            "hasMore": {
                                "Name": "hasMore",
                                "Type": "boolean",
                                "Description": "",
                                "Attributes": []
                            },
                            "query": {
                                "itemsPerPage": {
                                    "Name": "itemsPerPage",
                                    "Type": "int32",
                                    "Description": "",
                                    "Attributes": []
                                },
                                "currentPage": {
                                    "Name": "currentPage",
                                    "Type": "int32",
                                    "Description": "",
                                    "Attributes": []
                                },
                                "requestContinuationToken": {
                                    "Name": "requestContinuationToken",
                                    "Type": "string",
                                    "Description": "",
                                    "Attributes": []
                                }
                            },
                            "replacementContinuationToken": {
                                "Name": "replacementContinuationToken",
                                "Type": "string",
                                "Description": "",
                                "Attributes": []
                            },
                            "useTotalResults": {
                                "Name": "useTotalResults",
                                "Type": "boolean",
                                "Description": "If useTotalResults is true, then totalResults represents an accurate count.If False, it does not, and may be estimated/only the size of the current page.Either way, you should probably always only trust hasMore.This is a long-held historical throwback to when we used to do paging with known total results. Those queries toasted our database, and we were left to hastily alter our endpoints and create backward- compatible shims, of which useTotalResults is one.",
                                "Attributes": []
                            }
                        }
                    },
                    {
                        "categoryId": {
                            "Name": "categoryId",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        }
                    }
                ]
            }
        }


        .. seealso:: https://bungie-net.github.io/multi/operation_get_Trending-GetTrendingCategories.html#operation_get_Trending-GetTrendingCategories"""

        try:
            self.logger.info("Executing GetTrendingCategories...")
            url = self.base_url + "/Trending/Categories/".format()
            return await self.requester.request(method=HTTPMethod.GET, url=url)
        except Exception as ex:
            self.logger.exception(ex)

    async def GetTrendingCategory(self, categoryId: str, pageNumber: int) -> dict:
        """Returns paginated lists of trending items for a category.

            Args:
                categoryId (str): The ID of the category for whom you want additional results.
                pageNumber (int): The page # of results to return.

            Returns:
        {
            "results": {
                "Name": "results",
                "Type": "array",
                "Description": "",
                "Attributes": [],
                "Array Contents": [
                    {
                        "weight": {
                            "Name": "weight",
                            "Type": "double",
                            "Description": "The weighted score of this trending item.",
                            "Attributes": []
                        }
                    },
                    {
                        "isFeatured": {
                            "Name": "isFeatured",
                            "Type": "boolean",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "identifier": {
                            "Name": "identifier",
                            "Type": "string",
                            "Description": "We don't know whether the identifier will be a string, a uint, or a long... so we're going to cast it all to a string. But either way, we need any trending item created to have a single unique identifier for its type.",
                            "Attributes": []
                        }
                    },
                    {
                        "entityType": {
                            "Name": "entityType",
                            "Type": "int32",
                            "Description": "An enum - unfortunately - dictating all of the possible kinds of trending items that you might get in your result set, in case you want to do custom rendering or call to get the details of the item.",
                            "Attributes": []
                        }
                    },
                    {
                        "displayName": {
                            "Name": "displayName",
                            "Type": "string",
                            "Description": "The localized \"display name/article title/'primary localized identifier'\" of the entity.",
                            "Attributes": []
                        }
                    },
                    {
                        "tagline": {
                            "Name": "tagline",
                            "Type": "string",
                            "Description": "If the entity has a localized tagline/subtitle/motto/whatever, that is found here.",
                            "Attributes": []
                        }
                    },
                    {
                        "image": {
                            "Name": "image",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "startDate": {
                            "Name": "startDate",
                            "Type": "date-time",
                            "Description": "",
                            "Attributes": [
                                "Nullable"
                            ]
                        }
                    },
                    {
                        "endDate": {
                            "Name": "endDate",
                            "Type": "date-time",
                            "Description": "",
                            "Attributes": [
                                "Nullable"
                            ]
                        }
                    },
                    {
                        "link": {
                            "Name": "link",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "webmVideo": {
                            "Name": "webmVideo",
                            "Type": "string",
                            "Description": "If this is populated, the entry has a related WebM video to show. I am 100% certain I am going to regret putting this directly on TrendingEntry, but it will work so yolo",
                            "Attributes": []
                        }
                    },
                    {
                        "mp4Video": {
                            "Name": "mp4Video",
                            "Type": "string",
                            "Description": "If this is populated, the entry has a related MP4 video to show. I am 100% certain I am going to regret putting this directly on TrendingEntry, but it will work so yolo",
                            "Attributes": []
                        }
                    },
                    {
                        "featureImage": {
                            "Name": "featureImage",
                            "Type": "string",
                            "Description": "If isFeatured, this image will be populated with whatever the featured image is. Note that this will likely be a very large image, so don't use it all the time.",
                            "Attributes": []
                        }
                    },
                    {
                        "items": {
                            "Name": "items",
                            "Type": "array",
                            "Description": "If the item is of entityType TrendingEntryType.Container, it may have items - also Trending Entries - contained within it. This is the ordered list of those to display under the Container's header.",
                            "Attributes": []
                        }
                    },
                    {
                        "creationDate": {
                            "Name": "creationDate",
                            "Type": "date-time",
                            "Description": "If the entry has a date at which it was created, this is that date.",
                            "Attributes": [
                                "Nullable"
                            ]
                        }
                    }
                ]
            },
            "totalResults": {
                "Name": "totalResults",
                "Type": "int32",
                "Description": "",
                "Attributes": []
            },
            "hasMore": {
                "Name": "hasMore",
                "Type": "boolean",
                "Description": "",
                "Attributes": []
            },
            "query": {
                "itemsPerPage": {
                    "Name": "itemsPerPage",
                    "Type": "int32",
                    "Description": "",
                    "Attributes": []
                },
                "currentPage": {
                    "Name": "currentPage",
                    "Type": "int32",
                    "Description": "",
                    "Attributes": []
                },
                "requestContinuationToken": {
                    "Name": "requestContinuationToken",
                    "Type": "string",
                    "Description": "",
                    "Attributes": []
                }
            },
            "replacementContinuationToken": {
                "Name": "replacementContinuationToken",
                "Type": "string",
                "Description": "",
                "Attributes": []
            },
            "useTotalResults": {
                "Name": "useTotalResults",
                "Type": "boolean",
                "Description": "If useTotalResults is true, then totalResults represents an accurate count.If False, it does not, and may be estimated/only the size of the current page.Either way, you should probably always only trust hasMore.This is a long-held historical throwback to when we used to do paging with known total results. Those queries toasted our database, and we were left to hastily alter our endpoints and create backward- compatible shims, of which useTotalResults is one.",
                "Attributes": []
            }
        }


        .. seealso:: https://bungie-net.github.io/multi/operation_get_Trending-GetTrendingCategory.html#operation_get_Trending-GetTrendingCategory"""

        try:
            self.logger.info("Executing GetTrendingCategory...")
            url = (
                self.base_url
                + f"/Trending/Categories/{categoryId}/{pageNumber}/".format(
                    categoryId=categoryId, pageNumber=pageNumber
                )
            )
            return await self.requester.request(method=HTTPMethod.GET, url=url)
        except Exception as ex:
            self.logger.exception(ex)

    async def GetTrendingEntryDetail(
        self, identifier: str, trendingEntryType: int
    ) -> dict:
        """Returns the detailed results for a specific trending entry. Note that trending entries are uniquely identified by a combination of *both* the TrendingEntryType *and* the identifier: the identifier alone is not guaranteed to be globally unique.

            Args:
                identifier (str): The identifier for the entity to be returned.
                trendingEntryType (int): The type of entity to be returned.

            Returns:
        {
            "identifier": {
                "Name": "identifier",
                "Type": "string",
                "Description": "",
                "Attributes": []
            },
            "entityType": {
                "Name": "entityType",
                "Type": "int32",
                "Description": "",
                "Attributes": []
            },
            "news": {
                "article": {
                    "contentId": {
                        "Name": "contentId",
                        "Type": "int64",
                        "Description": "",
                        "Attributes": []
                    },
                    "cType": {
                        "Name": "cType",
                        "Type": "string",
                        "Description": "",
                        "Attributes": []
                    },
                    "cmsPath": {
                        "Name": "cmsPath",
                        "Type": "string",
                        "Description": "",
                        "Attributes": []
                    },
                    "creationDate": {
                        "Name": "creationDate",
                        "Type": "date-time",
                        "Description": "",
                        "Attributes": []
                    },
                    "modifyDate": {
                        "Name": "modifyDate",
                        "Type": "date-time",
                        "Description": "",
                        "Attributes": []
                    },
                    "allowComments": {
                        "Name": "allowComments",
                        "Type": "boolean",
                        "Description": "",
                        "Attributes": []
                    },
                    "hasAgeGate": {
                        "Name": "hasAgeGate",
                        "Type": "boolean",
                        "Description": "",
                        "Attributes": []
                    },
                    "minimumAge": {
                        "Name": "minimumAge",
                        "Type": "int32",
                        "Description": "",
                        "Attributes": []
                    },
                    "ratingImagePath": {
                        "Name": "ratingImagePath",
                        "Type": "string",
                        "Description": "",
                        "Attributes": []
                    },
                    "author": {
                        "membershipId": {
                            "Name": "membershipId",
                            "Type": "int64",
                            "Description": "",
                            "Attributes": []
                        },
                        "uniqueName": {
                            "Name": "uniqueName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "normalizedName": {
                            "Name": "normalizedName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "displayName": {
                            "Name": "displayName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "profilePicture": {
                            "Name": "profilePicture",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": []
                        },
                        "profileTheme": {
                            "Name": "profileTheme",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": []
                        },
                        "userTitle": {
                            "Name": "userTitle",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": []
                        },
                        "successMessageFlags": {
                            "Name": "successMessageFlags",
                            "Type": "int64",
                            "Description": "",
                            "Attributes": []
                        },
                        "isDeleted": {
                            "Name": "isDeleted",
                            "Type": "boolean",
                            "Description": "",
                            "Attributes": []
                        },
                        "about": {
                            "Name": "about",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "firstAccess": {
                            "Name": "firstAccess",
                            "Type": "date-time",
                            "Description": "",
                            "Attributes": [
                                "Nullable"
                            ]
                        },
                        "lastUpdate": {
                            "Name": "lastUpdate",
                            "Type": "date-time",
                            "Description": "",
                            "Attributes": [
                                "Nullable"
                            ]
                        },
                        "legacyPortalUID": {
                            "Name": "legacyPortalUID",
                            "Type": "int64",
                            "Description": "",
                            "Attributes": [
                                "Nullable"
                            ]
                        },
                        "context": {
                            "isFollowing": {
                                "Name": "isFollowing",
                                "Type": "boolean",
                                "Description": "",
                                "Attributes": []
                            },
                            "ignoreStatus": {
                                "isIgnored": {
                                    "Name": "isIgnored",
                                    "Type": "boolean",
                                    "Description": "",
                                    "Attributes": []
                                },
                                "ignoreFlags": {
                                    "Name": "ignoreFlags",
                                    "Type": "int32",
                                    "Description": "",
                                    "Attributes": []
                                }
                            },
                            "globalIgnoreEndDate": {
                                "Name": "globalIgnoreEndDate",
                                "Type": "date-time",
                                "Description": "",
                                "Attributes": [
                                    "Nullable"
                                ]
                            }
                        },
                        "psnDisplayName": {
                            "Name": "psnDisplayName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "xboxDisplayName": {
                            "Name": "xboxDisplayName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "fbDisplayName": {
                            "Name": "fbDisplayName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "showActivity": {
                            "Name": "showActivity",
                            "Type": "boolean",
                            "Description": "",
                            "Attributes": [
                                "Nullable"
                            ]
                        },
                        "locale": {
                            "Name": "locale",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "localeInheritDefault": {
                            "Name": "localeInheritDefault",
                            "Type": "boolean",
                            "Description": "",
                            "Attributes": []
                        },
                        "lastBanReportId": {
                            "Name": "lastBanReportId",
                            "Type": "int64",
                            "Description": "",
                            "Attributes": [
                                "Nullable"
                            ]
                        },
                        "showGroupMessaging": {
                            "Name": "showGroupMessaging",
                            "Type": "boolean",
                            "Description": "",
                            "Attributes": []
                        },
                        "profilePicturePath": {
                            "Name": "profilePicturePath",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "profilePictureWidePath": {
                            "Name": "profilePictureWidePath",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "profileThemeName": {
                            "Name": "profileThemeName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "userTitleDisplay": {
                            "Name": "userTitleDisplay",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "statusText": {
                            "Name": "statusText",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "statusDate": {
                            "Name": "statusDate",
                            "Type": "date-time",
                            "Description": "",
                            "Attributes": []
                        },
                        "profileBanExpire": {
                            "Name": "profileBanExpire",
                            "Type": "date-time",
                            "Description": "",
                            "Attributes": [
                                "Nullable"
                            ]
                        },
                        "blizzardDisplayName": {
                            "Name": "blizzardDisplayName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "steamDisplayName": {
                            "Name": "steamDisplayName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "stadiaDisplayName": {
                            "Name": "stadiaDisplayName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "twitchDisplayName": {
                            "Name": "twitchDisplayName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "cachedBungieGlobalDisplayName": {
                            "Name": "cachedBungieGlobalDisplayName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "cachedBungieGlobalDisplayNameCode": {
                            "Name": "cachedBungieGlobalDisplayNameCode",
                            "Type": "int16",
                            "Description": "",
                            "Attributes": [
                                "Nullable"
                            ]
                        },
                        "egsDisplayName": {
                            "Name": "egsDisplayName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    "autoEnglishPropertyFallback": {
                        "Name": "autoEnglishPropertyFallback",
                        "Type": "boolean",
                        "Description": "",
                        "Attributes": []
                    },
                    "properties": {
                        "Name": "properties",
                        "Type": "object",
                        "Description": "Firehose content is really a collection of metadata and \"properties\", which are the potentially-but-not-strictly localizable data that comprises the meat of whatever content is being shown.As Cole Porter would have crooned, \"Anything Goes\" with Firehose properties. They are most often strings, but they can theoretically be anything. They are JSON encoded, and could be JSON structures, simple strings, numbers etc... The Content Type of the item (cType) will describe the properties, and thus how they ought to be deserialized.",
                        "Attributes": []
                    },
                    "representations": {
                        "Name": "representations",
                        "Type": "array",
                        "Description": "",
                        "Attributes": [],
                        "Array Contents": [
                            {
                                "name": {
                                    "Name": "name",
                                    "Type": "string",
                                    "Description": "",
                                    "Attributes": []
                                }
                            },
                            {
                                "path": {
                                    "Name": "path",
                                    "Type": "string",
                                    "Description": "",
                                    "Attributes": []
                                }
                            },
                            {
                                "validationString": {
                                    "Name": "validationString",
                                    "Type": "string",
                                    "Description": "",
                                    "Attributes": []
                                }
                            }
                        ]
                    },
                    "tags": {
                        "Name": "tags",
                        "Type": "array",
                        "Description": "NOTE: Tags will always be lower case.",
                        "Attributes": [],
                        "Array Contents": "string"
                    },
                    "commentSummary": {
                        "topicId": {
                            "Name": "topicId",
                            "Type": "int64",
                            "Description": "",
                            "Attributes": []
                        },
                        "commentCount": {
                            "Name": "commentCount",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": []
                        }
                    }
                }
            },
            "support": {
                "article": {
                    "contentId": {
                        "Name": "contentId",
                        "Type": "int64",
                        "Description": "",
                        "Attributes": []
                    },
                    "cType": {
                        "Name": "cType",
                        "Type": "string",
                        "Description": "",
                        "Attributes": []
                    },
                    "cmsPath": {
                        "Name": "cmsPath",
                        "Type": "string",
                        "Description": "",
                        "Attributes": []
                    },
                    "creationDate": {
                        "Name": "creationDate",
                        "Type": "date-time",
                        "Description": "",
                        "Attributes": []
                    },
                    "modifyDate": {
                        "Name": "modifyDate",
                        "Type": "date-time",
                        "Description": "",
                        "Attributes": []
                    },
                    "allowComments": {
                        "Name": "allowComments",
                        "Type": "boolean",
                        "Description": "",
                        "Attributes": []
                    },
                    "hasAgeGate": {
                        "Name": "hasAgeGate",
                        "Type": "boolean",
                        "Description": "",
                        "Attributes": []
                    },
                    "minimumAge": {
                        "Name": "minimumAge",
                        "Type": "int32",
                        "Description": "",
                        "Attributes": []
                    },
                    "ratingImagePath": {
                        "Name": "ratingImagePath",
                        "Type": "string",
                        "Description": "",
                        "Attributes": []
                    },
                    "author": {
                        "membershipId": {
                            "Name": "membershipId",
                            "Type": "int64",
                            "Description": "",
                            "Attributes": []
                        },
                        "uniqueName": {
                            "Name": "uniqueName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "normalizedName": {
                            "Name": "normalizedName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "displayName": {
                            "Name": "displayName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "profilePicture": {
                            "Name": "profilePicture",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": []
                        },
                        "profileTheme": {
                            "Name": "profileTheme",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": []
                        },
                        "userTitle": {
                            "Name": "userTitle",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": []
                        },
                        "successMessageFlags": {
                            "Name": "successMessageFlags",
                            "Type": "int64",
                            "Description": "",
                            "Attributes": []
                        },
                        "isDeleted": {
                            "Name": "isDeleted",
                            "Type": "boolean",
                            "Description": "",
                            "Attributes": []
                        },
                        "about": {
                            "Name": "about",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "firstAccess": {
                            "Name": "firstAccess",
                            "Type": "date-time",
                            "Description": "",
                            "Attributes": [
                                "Nullable"
                            ]
                        },
                        "lastUpdate": {
                            "Name": "lastUpdate",
                            "Type": "date-time",
                            "Description": "",
                            "Attributes": [
                                "Nullable"
                            ]
                        },
                        "legacyPortalUID": {
                            "Name": "legacyPortalUID",
                            "Type": "int64",
                            "Description": "",
                            "Attributes": [
                                "Nullable"
                            ]
                        },
                        "context": {
                            "isFollowing": {
                                "Name": "isFollowing",
                                "Type": "boolean",
                                "Description": "",
                                "Attributes": []
                            },
                            "ignoreStatus": {
                                "isIgnored": {
                                    "Name": "isIgnored",
                                    "Type": "boolean",
                                    "Description": "",
                                    "Attributes": []
                                },
                                "ignoreFlags": {
                                    "Name": "ignoreFlags",
                                    "Type": "int32",
                                    "Description": "",
                                    "Attributes": []
                                }
                            },
                            "globalIgnoreEndDate": {
                                "Name": "globalIgnoreEndDate",
                                "Type": "date-time",
                                "Description": "",
                                "Attributes": [
                                    "Nullable"
                                ]
                            }
                        },
                        "psnDisplayName": {
                            "Name": "psnDisplayName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "xboxDisplayName": {
                            "Name": "xboxDisplayName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "fbDisplayName": {
                            "Name": "fbDisplayName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "showActivity": {
                            "Name": "showActivity",
                            "Type": "boolean",
                            "Description": "",
                            "Attributes": [
                                "Nullable"
                            ]
                        },
                        "locale": {
                            "Name": "locale",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "localeInheritDefault": {
                            "Name": "localeInheritDefault",
                            "Type": "boolean",
                            "Description": "",
                            "Attributes": []
                        },
                        "lastBanReportId": {
                            "Name": "lastBanReportId",
                            "Type": "int64",
                            "Description": "",
                            "Attributes": [
                                "Nullable"
                            ]
                        },
                        "showGroupMessaging": {
                            "Name": "showGroupMessaging",
                            "Type": "boolean",
                            "Description": "",
                            "Attributes": []
                        },
                        "profilePicturePath": {
                            "Name": "profilePicturePath",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "profilePictureWidePath": {
                            "Name": "profilePictureWidePath",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "profileThemeName": {
                            "Name": "profileThemeName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "userTitleDisplay": {
                            "Name": "userTitleDisplay",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "statusText": {
                            "Name": "statusText",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "statusDate": {
                            "Name": "statusDate",
                            "Type": "date-time",
                            "Description": "",
                            "Attributes": []
                        },
                        "profileBanExpire": {
                            "Name": "profileBanExpire",
                            "Type": "date-time",
                            "Description": "",
                            "Attributes": [
                                "Nullable"
                            ]
                        },
                        "blizzardDisplayName": {
                            "Name": "blizzardDisplayName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "steamDisplayName": {
                            "Name": "steamDisplayName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "stadiaDisplayName": {
                            "Name": "stadiaDisplayName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "twitchDisplayName": {
                            "Name": "twitchDisplayName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "cachedBungieGlobalDisplayName": {
                            "Name": "cachedBungieGlobalDisplayName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        },
                        "cachedBungieGlobalDisplayNameCode": {
                            "Name": "cachedBungieGlobalDisplayNameCode",
                            "Type": "int16",
                            "Description": "",
                            "Attributes": [
                                "Nullable"
                            ]
                        },
                        "egsDisplayName": {
                            "Name": "egsDisplayName",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    "autoEnglishPropertyFallback": {
                        "Name": "autoEnglishPropertyFallback",
                        "Type": "boolean",
                        "Description": "",
                        "Attributes": []
                    },
                    "properties": {
                        "Name": "properties",
                        "Type": "object",
                        "Description": "Firehose content is really a collection of metadata and \"properties\", which are the potentially-but-not-strictly localizable data that comprises the meat of whatever content is being shown.As Cole Porter would have crooned, \"Anything Goes\" with Firehose properties. They are most often strings, but they can theoretically be anything. They are JSON encoded, and could be JSON structures, simple strings, numbers etc... The Content Type of the item (cType) will describe the properties, and thus how they ought to be deserialized.",
                        "Attributes": []
                    },
                    "representations": {
                        "Name": "representations",
                        "Type": "array",
                        "Description": "",
                        "Attributes": [],
                        "Array Contents": [
                            {
                                "name": {
                                    "Name": "name",
                                    "Type": "string",
                                    "Description": "",
                                    "Attributes": []
                                }
                            },
                            {
                                "path": {
                                    "Name": "path",
                                    "Type": "string",
                                    "Description": "",
                                    "Attributes": []
                                }
                            },
                            {
                                "validationString": {
                                    "Name": "validationString",
                                    "Type": "string",
                                    "Description": "",
                                    "Attributes": []
                                }
                            }
                        ]
                    },
                    "tags": {
                        "Name": "tags",
                        "Type": "array",
                        "Description": "NOTE: Tags will always be lower case.",
                        "Attributes": [],
                        "Array Contents": "string"
                    },
                    "commentSummary": {
                        "topicId": {
                            "Name": "topicId",
                            "Type": "int64",
                            "Description": "",
                            "Attributes": []
                        },
                        "commentCount": {
                            "Name": "commentCount",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": []
                        }
                    }
                }
            },
            "destinyItem": {
                "itemHash": {
                    "Name": "itemHash",
                    "Type": "uint32",
                    "Description": "",
                    "Attributes": []
                }
            },
            "destinyActivity": {
                "activityHash": {
                    "Name": "activityHash",
                    "Type": "uint32",
                    "Description": "",
                    "Attributes": []
                },
                "status": {
                    "challengeObjectiveHashes": {
                        "Name": "challengeObjectiveHashes",
                        "Type": "array",
                        "Description": "Active Challenges for the activity, if any - represented as hashes for DestinyObjectiveDefinitions.",
                        "Attributes": [
                            "Mapped to Definition"
                        ],
                        "Array Contents": "uint32"
                    },
                    "modifierHashes": {
                        "Name": "modifierHashes",
                        "Type": "array",
                        "Description": "The active modifiers on this activity, if any - represented as hashes for DestinyActivityModifierDefinitions.",
                        "Attributes": [
                            "Mapped to Definition"
                        ],
                        "Array Contents": "uint32"
                    },
                    "rewardTooltipItems": {
                        "Name": "rewardTooltipItems",
                        "Type": "array",
                        "Description": "If the activity itself provides any specific \"mock\" rewards, this will be the items and their quantity.Why \"mock\", you ask? Because these are the rewards as they are represented in the tooltip of the Activity.These are often pointers to fake items that look good in a tooltip, but represent an abstract concept of what you will get for a reward rather than the specific items you may obtain.",
                        "Attributes": [],
                        "Array Contents": [
                            {
                                "itemHash": {
                                    "Name": "itemHash",
                                    "Type": "uint32",
                                    "Description": "The hash identifier for the item in question. Use it to look up the item's DestinyInventoryItemDefinition.",
                                    "Attributes": [
                                        "Mapped to Definition"
                                    ]
                                }
                            },
                            {
                                "itemInstanceId": {
                                    "Name": "itemInstanceId",
                                    "Type": "int64",
                                    "Description": "If this quantity is referring to a specific instance of an item, this will have the item's instance ID. Normally, this will be null.",
                                    "Attributes": [
                                        "Nullable"
                                    ]
                                }
                            },
                            {
                                "quantity": {
                                    "Name": "quantity",
                                    "Type": "int32",
                                    "Description": "The amount of the item needed/available depending on the context of where DestinyItemQuantity is being used.",
                                    "Attributes": []
                                }
                            },
                            {
                                "hasConditionalVisibility": {
                                    "Name": "hasConditionalVisibility",
                                    "Type": "boolean",
                                    "Description": "Indicates that this item quantity may be conditionally shown or hidden, based on various sources of state. For example: server flags, account state, or character progress.",
                                    "Attributes": []
                                }
                            }
                        ]
                    }
                }
            },
            "destinyRitual": {
                "image": {
                    "Name": "image",
                    "Type": "string",
                    "Description": "",
                    "Attributes": []
                },
                "icon": {
                    "Name": "icon",
                    "Type": "string",
                    "Description": "",
                    "Attributes": []
                },
                "title": {
                    "Name": "title",
                    "Type": "string",
                    "Description": "",
                    "Attributes": []
                },
                "subtitle": {
                    "Name": "subtitle",
                    "Type": "string",
                    "Description": "",
                    "Attributes": []
                },
                "dateStart": {
                    "Name": "dateStart",
                    "Type": "date-time",
                    "Description": "",
                    "Attributes": [
                        "Nullable"
                    ]
                },
                "dateEnd": {
                    "Name": "dateEnd",
                    "Type": "date-time",
                    "Description": "",
                    "Attributes": [
                        "Nullable"
                    ]
                },
                "milestoneDetails": {
                    "Name": "milestoneDetails",
                    "Type": "object",
                    "Description": "A destiny event does not necessarily have a related Milestone, but if it does the details will be returned here.",
                    "Attributes": []
                },
                "eventContent": {
                    "Name": "eventContent",
                    "Type": "object",
                    "Description": "A destiny event will not necessarily have milestone \"custom content\", but if it does the details will be here.",
                    "Attributes": []
                }
            },
            "creation": {
                "media": {
                    "Name": "media",
                    "Type": "string",
                    "Description": "",
                    "Attributes": []
                },
                "title": {
                    "Name": "title",
                    "Type": "string",
                    "Description": "",
                    "Attributes": []
                },
                "author": {
                    "Name": "author",
                    "Type": "string",
                    "Description": "",
                    "Attributes": []
                },
                "authorMembershipId": {
                    "Name": "authorMembershipId",
                    "Type": "int64",
                    "Description": "",
                    "Attributes": []
                },
                "postId": {
                    "Name": "postId",
                    "Type": "int64",
                    "Description": "",
                    "Attributes": []
                },
                "body": {
                    "Name": "body",
                    "Type": "string",
                    "Description": "",
                    "Attributes": []
                },
                "upvotes": {
                    "Name": "upvotes",
                    "Type": "int32",
                    "Description": "",
                    "Attributes": []
                }
            }
        }


        .. seealso:: https://bungie-net.github.io/multi/operation_get_Trending-GetTrendingEntryDetail.html#operation_get_Trending-GetTrendingEntryDetail"""

        try:
            self.logger.info("Executing GetTrendingEntryDetail...")
            url = (
                self.base_url
                + f"/Trending/Details/{trendingEntryType}/{identifier}/".format(
                    identifier=identifier, trendingEntryType=trendingEntryType
                )
            )
            return await self.requester.request(method=HTTPMethod.GET, url=url)
        except Exception as ex:
            self.logger.exception(ex)



from destipy.utils.http_method import HTTPMethod
from destipy.utils.requester import Requester


class Fireteam:
    """Fireteam endpoints."""

    def __init__(self, requester, logger):
        self.requester: Requester = requester
        self.logger = logger
        self.base_url = "https://www.bungie.net/Platform"

    async def GetActivePrivateClanFireteamCount(
        self, groupId: int, access_token: str
    ) -> dict:
        """Gets a count of all active non-public fireteams for the specified clan. Maximum value returned is 25.

            Args:
                groupId (int): The group id of the clan.
                access_token (str): OAuth token

            Returns:
        {
            "Name": "Response",
            "Type": "int32",
            "Description": "",
            "Attributes": []
        }


        .. seealso:: https://bungie-net.github.io/multi/operation_get_Fireteam-GetActivePrivateClanFireteamCount.html#operation_get_Fireteam-GetActivePrivateClanFireteamCount"""

        try:
            self.logger.info("Executing GetActivePrivateClanFireteamCount...")
            url = self.base_url + f"/Fireteam/Clan/{groupId}/ActiveCount/".format(
                groupId=groupId
            )
            return await self.requester.request(
                method=HTTPMethod.GET, url=url, access_token=access_token
            )
        except Exception as ex:
            self.logger.exception(ex)

    async def GetAvailableClanFireteams(
        self,
        activityType: int,
        dateRange: int,
        groupId: int,
        page: int,
        platform: int,
        publicOnly: int,
        slotFilter: int,
        excludeImmediate: bool,
        langFilter: str,
        access_token: str,
    ) -> dict:
        """Gets a listing of all of this clan's fireteams that are have available slots. Caller is not checked for join criteria so caching is maximized.

            Args:
                activityType (int): The activity type to filter by.
                dateRange (int): The date range to grab available fireteams.
                groupId (int): The group id of the clan.
                page (int): Zero based page
                platform (int): The platform filter.
                publicOnly (int): Determines public/private filtering.
                slotFilter (int): Filters based on available slots
                excludeImmediate (bool): If you wish the result to exclude immediate fireteams, set this to true. Immediate-only can be forced using the dateRange enum.
                langFilter (str): An optional language filter.
                access_token (str): OAuth token

            Returns:
        {
            "results": {
                "Name": "results",
                "Type": "array",
                "Description": "",
                "Attributes": [],
                "Array Contents": [
                    {
                        "fireteamId": {
                            "Name": "fireteamId",
                            "Type": "int64",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "groupId": {
                            "Name": "groupId",
                            "Type": "int64",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "platform": {
                            "Name": "platform",
                            "Type": "byte",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "activityType": {
                            "Name": "activityType",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "isImmediate": {
                            "Name": "isImmediate",
                            "Type": "boolean",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "scheduledTime": {
                            "Name": "scheduledTime",
                            "Type": "date-time",
                            "Description": "",
                            "Attributes": [
                                "Nullable"
                            ]
                        }
                    },
                    {
                        "ownerMembershipId": {
                            "Name": "ownerMembershipId",
                            "Type": "int64",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "playerSlotCount": {
                            "Name": "playerSlotCount",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "alternateSlotCount": {
                            "Name": "alternateSlotCount",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": [
                                "Nullable"
                            ]
                        }
                    },
                    {
                        "availablePlayerSlotCount": {
                            "Name": "availablePlayerSlotCount",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "availableAlternateSlotCount": {
                            "Name": "availableAlternateSlotCount",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "title": {
                            "Name": "title",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "dateCreated": {
                            "Name": "dateCreated",
                            "Type": "date-time",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "dateModified": {
                            "Name": "dateModified",
                            "Type": "date-time",
                            "Description": "",
                            "Attributes": [
                                "Nullable"
                            ]
                        }
                    },
                    {
                        "isPublic": {
                            "Name": "isPublic",
                            "Type": "boolean",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "locale": {
                            "Name": "locale",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "isValid": {
                            "Name": "isValid",
                            "Type": "boolean",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "datePlayerModified": {
                            "Name": "datePlayerModified",
                            "Type": "date-time",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "titleBeforeModeration": {
                            "Name": "titleBeforeModeration",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "ownerCurrentGuardianRankSnapshot": {
                            "Name": "ownerCurrentGuardianRankSnapshot",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": [
                                "Mapped to Definition"
                            ]
                        }
                    },
                    {
                        "ownerHighestLifetimeGuardianRankSnapshot": {
                            "Name": "ownerHighestLifetimeGuardianRankSnapshot",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": [
                                "Mapped to Definition"
                            ]
                        }
                    },
                    {
                        "ownerTotalCommendationScoreSnapshot": {
                            "Name": "ownerTotalCommendationScoreSnapshot",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": []
                        }
                    }
                ]
            },
            "totalResults": {
                "Name": "totalResults",
                "Type": "int32",
                "Description": "",
                "Attributes": []
            },
            "hasMore": {
                "Name": "hasMore",
                "Type": "boolean",
                "Description": "",
                "Attributes": []
            },
            "query": {
                "itemsPerPage": {
                    "Name": "itemsPerPage",
                    "Type": "int32",
                    "Description": "",
                    "Attributes": []
                },
                "currentPage": {
                    "Name": "currentPage",
                    "Type": "int32",
                    "Description": "",
                    "Attributes": []
                },
                "requestContinuationToken": {
                    "Name": "requestContinuationToken",
                    "Type": "string",
                    "Description": "",
                    "Attributes": []
                }
            },
            "replacementContinuationToken": {
                "Name": "replacementContinuationToken",
                "Type": "string",
                "Description": "",
                "Attributes": []
            },
            "useTotalResults": {
                "Name": "useTotalResults",
                "Type": "boolean",
                "Description": "If useTotalResults is true, then totalResults represents an accurate count.If False, it does not, and may be estimated/only the size of the current page.Either way, you should probably always only trust hasMore.This is a long-held historical throwback to when we used to do paging with known total results. Those queries toasted our database, and we were left to hastily alter our endpoints and create backward- compatible shims, of which useTotalResults is one.",
                "Attributes": []
            }
        }


        .. seealso:: https://bungie-net.github.io/multi/operation_get_Fireteam-GetAvailableClanFireteams.html#operation_get_Fireteam-GetAvailableClanFireteams"""

        try:
            self.logger.info("Executing GetAvailableClanFireteams...")
            url = (
                self.base_url
                + f"/Fireteam/Clan/{groupId}/Available/{platform}/{activityType}/{dateRange}/{slotFilter}/{publicOnly}/{page}/".format(
                    activityType=activityType,
                    dateRange=dateRange,
                    groupId=groupId,
                    page=page,
                    platform=platform,
                    publicOnly=publicOnly,
                    slotFilter=slotFilter,
                    excludeImmediate=excludeImmediate,
                    langFilter=langFilter,
                )
            )
            return await self.requester.request(
                method=HTTPMethod.GET, url=url, access_token=access_token
            )
        except Exception as ex:
            self.logger.exception(ex)

    async def SearchPublicAvailableClanFireteams(
        self,
        activityType: int,
        dateRange: int,
        page: int,
        platform: int,
        slotFilter: int,
        excludeImmediate: bool,
        langFilter: str,
        access_token: str,
    ) -> dict:
        """Gets a listing of all public fireteams starting now with open slots. Caller is not checked for join criteria so caching is maximized.

            Args:
                activityType (int): The activity type to filter by.
                dateRange (int): The date range to grab available fireteams.
                page (int): Zero based page
                platform (int): The platform filter.
                slotFilter (int): Filters based on available slots
                excludeImmediate (bool): If you wish the result to exclude immediate fireteams, set this to true. Immediate-only can be forced using the dateRange enum.
                langFilter (str): An optional language filter.
                access_token (str): OAuth token

            Returns:
        {
            "results": {
                "Name": "results",
                "Type": "array",
                "Description": "",
                "Attributes": [],
                "Array Contents": [
                    {
                        "fireteamId": {
                            "Name": "fireteamId",
                            "Type": "int64",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "groupId": {
                            "Name": "groupId",
                            "Type": "int64",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "platform": {
                            "Name": "platform",
                            "Type": "byte",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "activityType": {
                            "Name": "activityType",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "isImmediate": {
                            "Name": "isImmediate",
                            "Type": "boolean",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "scheduledTime": {
                            "Name": "scheduledTime",
                            "Type": "date-time",
                            "Description": "",
                            "Attributes": [
                                "Nullable"
                            ]
                        }
                    },
                    {
                        "ownerMembershipId": {
                            "Name": "ownerMembershipId",
                            "Type": "int64",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "playerSlotCount": {
                            "Name": "playerSlotCount",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "alternateSlotCount": {
                            "Name": "alternateSlotCount",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": [
                                "Nullable"
                            ]
                        }
                    },
                    {
                        "availablePlayerSlotCount": {
                            "Name": "availablePlayerSlotCount",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "availableAlternateSlotCount": {
                            "Name": "availableAlternateSlotCount",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "title": {
                            "Name": "title",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "dateCreated": {
                            "Name": "dateCreated",
                            "Type": "date-time",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "dateModified": {
                            "Name": "dateModified",
                            "Type": "date-time",
                            "Description": "",
                            "Attributes": [
                                "Nullable"
                            ]
                        }
                    },
                    {
                        "isPublic": {
                            "Name": "isPublic",
                            "Type": "boolean",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "locale": {
                            "Name": "locale",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "isValid": {
                            "Name": "isValid",
                            "Type": "boolean",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "datePlayerModified": {
                            "Name": "datePlayerModified",
                            "Type": "date-time",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "titleBeforeModeration": {
                            "Name": "titleBeforeModeration",
                            "Type": "string",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "ownerCurrentGuardianRankSnapshot": {
                            "Name": "ownerCurrentGuardianRankSnapshot",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": [
                                "Mapped to Definition"
                            ]
                        }
                    },
                    {
                        "ownerHighestLifetimeGuardianRankSnapshot": {
                            "Name": "ownerHighestLifetimeGuardianRankSnapshot",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": [
                                "Mapped to Definition"
                            ]
                        }
                    },
                    {
                        "ownerTotalCommendationScoreSnapshot": {
                            "Name": "ownerTotalCommendationScoreSnapshot",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": []
                        }
                    }
                ]
            },
            "totalResults": {
                "Name": "totalResults",
                "Type": "int32",
                "Description": "",
                "Attributes": []
            },
            "hasMore": {
                "Name": "hasMore",
                "Type": "boolean",
                "Description": "",
                "Attributes": []
            },
            "query": {
                "itemsPerPage": {
                    "Name": "itemsPerPage",
                    "Type": "int32",
                    "Description": "",
                    "Attributes": []
                },
                "currentPage": {
                    "Name": "currentPage",
                    "Type": "int32",
                    "Description": "",
                    "Attributes": []
                },
                "requestContinuationToken": {
                    "Name": "requestContinuationToken",
                    "Type": "string",
                    "Description": "",
                    "Attributes": []
                }
            },
            "replacementContinuationToken": {
                "Name": "replacementContinuationToken",
                "Type": "string",
                "Description": "",
                "Attributes": []
            },
            "useTotalResults": {
                "Name": "useTotalResults",
                "Type": "boolean",
                "Description": "If useTotalResults is true, then totalResults represents an accurate count.If False, it does not, and may be estimated/only the size of the current page.Either way, you should probably always only trust hasMore.This is a long-held historical throwback to when we used to do paging with known total results. Those queries toasted our database, and we were left to hastily alter our endpoints and create backward- compatible shims, of which useTotalResults is one.",
                "Attributes": []
            }
        }


        .. seealso:: https://bungie-net.github.io/multi/operation_get_Fireteam-SearchPublicAvailableClanFireteams.html#operation_get_Fireteam-SearchPublicAvailableClanFireteams"""

        try:
            self.logger.info("Executing SearchPublicAvailableClanFireteams...")
            url = (
                self.base_url
                + f"/Fireteam/Search/Available/{platform}/{activityType}/{dateRange}/{slotFilter}/{page}/".format(
                    activityType=activityType,
                    dateRange=dateRange,
                    page=page,
                    platform=platform,
                    slotFilter=slotFilter,
                    excludeImmediate=excludeImmediate,
                    langFilter=langFilter,
                )
            )
            return await self.requester.request(
                method=HTTPMethod.GET, url=url, access_token=access_token
            )
        except Exception as ex:
            self.logger.exception(ex)

    async def GetMyClanFireteams(
        self,
        groupId: int,
        includeClosed: bool,
        page: int,
        platform: int,
        groupFilter: bool,
        langFilter: str,
        access_token: str,
    ) -> dict:
        """Gets a listing of all fireteams that caller is an applicant, a member, or an alternate of.

            Args:
                groupId (int): The group id of the clan. (This parameter is ignored unless the optional query parameter groupFilter is true).
                includeClosed (bool): If true, return fireteams that have been closed.
                page (int): Deprecated parameter, ignored.
                platform (int): The platform filter.
                groupFilter (bool): If true, filter by clan. Otherwise, ignore the clan and show all of the user's fireteams.
                langFilter (str): An optional language filter.
                access_token (str): OAuth token

            Returns:
        {
            "results": {
                "Name": "results",
                "Type": "array",
                "Description": "",
                "Attributes": [],
                "Array Contents": [
                    {
                        "Summary": {
                            "fireteamId": {
                                "Name": "fireteamId",
                                "Type": "int64",
                                "Description": "",
                                "Attributes": []
                            },
                            "groupId": {
                                "Name": "groupId",
                                "Type": "int64",
                                "Description": "",
                                "Attributes": []
                            },
                            "platform": {
                                "Name": "platform",
                                "Type": "byte",
                                "Description": "",
                                "Attributes": []
                            },
                            "activityType": {
                                "Name": "activityType",
                                "Type": "int32",
                                "Description": "",
                                "Attributes": []
                            },
                            "isImmediate": {
                                "Name": "isImmediate",
                                "Type": "boolean",
                                "Description": "",
                                "Attributes": []
                            },
                            "scheduledTime": {
                                "Name": "scheduledTime",
                                "Type": "date-time",
                                "Description": "",
                                "Attributes": [
                                    "Nullable"
                                ]
                            },
                            "ownerMembershipId": {
                                "Name": "ownerMembershipId",
                                "Type": "int64",
                                "Description": "",
                                "Attributes": []
                            },
                            "playerSlotCount": {
                                "Name": "playerSlotCount",
                                "Type": "int32",
                                "Description": "",
                                "Attributes": []
                            },
                            "alternateSlotCount": {
                                "Name": "alternateSlotCount",
                                "Type": "int32",
                                "Description": "",
                                "Attributes": [
                                    "Nullable"
                                ]
                            },
                            "availablePlayerSlotCount": {
                                "Name": "availablePlayerSlotCount",
                                "Type": "int32",
                                "Description": "",
                                "Attributes": []
                            },
                            "availableAlternateSlotCount": {
                                "Name": "availableAlternateSlotCount",
                                "Type": "int32",
                                "Description": "",
                                "Attributes": []
                            },
                            "title": {
                                "Name": "title",
                                "Type": "string",
                                "Description": "",
                                "Attributes": []
                            },
                            "dateCreated": {
                                "Name": "dateCreated",
                                "Type": "date-time",
                                "Description": "",
                                "Attributes": []
                            },
                            "dateModified": {
                                "Name": "dateModified",
                                "Type": "date-time",
                                "Description": "",
                                "Attributes": [
                                    "Nullable"
                                ]
                            },
                            "isPublic": {
                                "Name": "isPublic",
                                "Type": "boolean",
                                "Description": "",
                                "Attributes": []
                            },
                            "locale": {
                                "Name": "locale",
                                "Type": "string",
                                "Description": "",
                                "Attributes": []
                            },
                            "isValid": {
                                "Name": "isValid",
                                "Type": "boolean",
                                "Description": "",
                                "Attributes": []
                            },
                            "datePlayerModified": {
                                "Name": "datePlayerModified",
                                "Type": "date-time",
                                "Description": "",
                                "Attributes": []
                            },
                            "titleBeforeModeration": {
                                "Name": "titleBeforeModeration",
                                "Type": "string",
                                "Description": "",
                                "Attributes": []
                            },
                            "ownerCurrentGuardianRankSnapshot": {
                                "Name": "ownerCurrentGuardianRankSnapshot",
                                "Type": "int32",
                                "Description": "",
                                "Attributes": [
                                    "Mapped to Definition"
                                ]
                            },
                            "ownerHighestLifetimeGuardianRankSnapshot": {
                                "Name": "ownerHighestLifetimeGuardianRankSnapshot",
                                "Type": "int32",
                                "Description": "",
                                "Attributes": [
                                    "Mapped to Definition"
                                ]
                            },
                            "ownerTotalCommendationScoreSnapshot": {
                                "Name": "ownerTotalCommendationScoreSnapshot",
                                "Type": "int32",
                                "Description": "",
                                "Attributes": []
                            }
                        }
                    },
                    {
                        "Members": {
                            "Name": "Members",
                            "Type": "array",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "Alternates": {
                            "Name": "Alternates",
                            "Type": "array",
                            "Description": "",
                            "Attributes": []
                        }
                    }
                ]
            },
            "totalResults": {
                "Name": "totalResults",
                "Type": "int32",
                "Description": "",
                "Attributes": []
            },
            "hasMore": {
                "Name": "hasMore",
                "Type": "boolean",
                "Description": "",
                "Attributes": []
            },
            "query": {
                "itemsPerPage": {
                    "Name": "itemsPerPage",
                    "Type": "int32",
                    "Description": "",
                    "Attributes": []
                },
                "currentPage": {
                    "Name": "currentPage",
                    "Type": "int32",
                    "Description": "",
                    "Attributes": []
                },
                "requestContinuationToken": {
                    "Name": "requestContinuationToken",
                    "Type": "string",
                    "Description": "",
                    "Attributes": []
                }
            },
            "replacementContinuationToken": {
                "Name": "replacementContinuationToken",
                "Type": "string",
                "Description": "",
                "Attributes": []
            },
            "useTotalResults": {
                "Name": "useTotalResults",
                "Type": "boolean",
                "Description": "If useTotalResults is true, then totalResults represents an accurate count.If False, it does not, and may be estimated/only the size of the current page.Either way, you should probably always only trust hasMore.This is a long-held historical throwback to when we used to do paging with known total results. Those queries toasted our database, and we were left to hastily alter our endpoints and create backward- compatible shims, of which useTotalResults is one.",
                "Attributes": []
            }
        }


        .. seealso:: https://bungie-net.github.io/multi/operation_get_Fireteam-GetMyClanFireteams.html#operation_get_Fireteam-GetMyClanFireteams"""

        try:
            self.logger.info("Executing GetMyClanFireteams...")
            url = (
                self.base_url
                + f"/Fireteam/Clan/{groupId}/My/{platform}/{includeClosed}/{page}/".format(
                    groupId=groupId,
                    includeClosed=includeClosed,
                    page=page,
                    platform=platform,
                    groupFilter=groupFilter,
                    langFilter=langFilter,
                )
            )
            return await self.requester.request(
                method=HTTPMethod.GET, url=url, access_token=access_token
            )
        except Exception as ex:
            self.logger.exception(ex)

    async def GetClanFireteam(
        self, fireteamId: int, groupId: int, access_token: str
    ) -> dict:
        """Gets a specific fireteam.

            Args:
                fireteamId (int): The unique id of the fireteam.
                groupId (int): The group id of the clan.
                access_token (str): OAuth token

            Returns:
        {
            "Summary": {
                "fireteamId": {
                    "Name": "fireteamId",
                    "Type": "int64",
                    "Description": "",
                    "Attributes": []
                },
                "groupId": {
                    "Name": "groupId",
                    "Type": "int64",
                    "Description": "",
                    "Attributes": []
                },
                "platform": {
                    "Name": "platform",
                    "Type": "byte",
                    "Description": "",
                    "Attributes": []
                },
                "activityType": {
                    "Name": "activityType",
                    "Type": "int32",
                    "Description": "",
                    "Attributes": []
                },
                "isImmediate": {
                    "Name": "isImmediate",
                    "Type": "boolean",
                    "Description": "",
                    "Attributes": []
                },
                "scheduledTime": {
                    "Name": "scheduledTime",
                    "Type": "date-time",
                    "Description": "",
                    "Attributes": [
                        "Nullable"
                    ]
                },
                "ownerMembershipId": {
                    "Name": "ownerMembershipId",
                    "Type": "int64",
                    "Description": "",
                    "Attributes": []
                },
                "playerSlotCount": {
                    "Name": "playerSlotCount",
                    "Type": "int32",
                    "Description": "",
                    "Attributes": []
                },
                "alternateSlotCount": {
                    "Name": "alternateSlotCount",
                    "Type": "int32",
                    "Description": "",
                    "Attributes": [
                        "Nullable"
                    ]
                },
                "availablePlayerSlotCount": {
                    "Name": "availablePlayerSlotCount",
                    "Type": "int32",
                    "Description": "",
                    "Attributes": []
                },
                "availableAlternateSlotCount": {
                    "Name": "availableAlternateSlotCount",
                    "Type": "int32",
                    "Description": "",
                    "Attributes": []
                },
                "title": {
                    "Name": "title",
                    "Type": "string",
                    "Description": "",
                    "Attributes": []
                },
                "dateCreated": {
                    "Name": "dateCreated",
                    "Type": "date-time",
                    "Description": "",
                    "Attributes": []
                },
                "dateModified": {
                    "Name": "dateModified",
                    "Type": "date-time",
                    "Description": "",
                    "Attributes": [
                        "Nullable"
                    ]
                },
                "isPublic": {
                    "Name": "isPublic",
                    "Type": "boolean",
                    "Description": "",
                    "Attributes": []
                },
                "locale": {
                    "Name": "locale",
                    "Type": "string",
                    "Description": "",
                    "Attributes": []
                },
                "isValid": {
                    "Name": "isValid",
                    "Type": "boolean",
                    "Description": "",
                    "Attributes": []
                },
                "datePlayerModified": {
                    "Name": "datePlayerModified",
                    "Type": "date-time",
                    "Description": "",
                    "Attributes": []
                },
                "titleBeforeModeration": {
                    "Name": "titleBeforeModeration",
                    "Type": "string",
                    "Description": "",
                    "Attributes": []
                },
                "ownerCurrentGuardianRankSnapshot": {
                    "Name": "ownerCurrentGuardianRankSnapshot",
                    "Type": "int32",
                    "Description": "",
                    "Attributes": [
                        "Mapped to Definition"
                    ]
                },
                "ownerHighestLifetimeGuardianRankSnapshot": {
                    "Name": "ownerHighestLifetimeGuardianRankSnapshot",
                    "Type": "int32",
                    "Description": "",
                    "Attributes": [
                        "Mapped to Definition"
                    ]
                },
                "ownerTotalCommendationScoreSnapshot": {
                    "Name": "ownerTotalCommendationScoreSnapshot",
                    "Type": "int32",
                    "Description": "",
                    "Attributes": []
                }
            },
            "Members": {
                "Name": "Members",
                "Type": "array",
                "Description": "",
                "Attributes": [],
                "Array Contents": [
                    {
                        "destinyUserInfo": {
                            "FireteamDisplayName": {
                                "Name": "FireteamDisplayName",
                                "Type": "string",
                                "Description": "",
                                "Attributes": []
                            },
                            "FireteamMembershipType": {
                                "Name": "FireteamMembershipType",
                                "Type": "int32",
                                "Description": "",
                                "Attributes": []
                            },
                            "supplementalDisplayName": {
                                "Name": "supplementalDisplayName",
                                "Type": "string",
                                "Description": "A platform specific additional display name - ex: psn Real Name, bnet Unique Name, etc.",
                                "Attributes": []
                            },
                            "iconPath": {
                                "Name": "iconPath",
                                "Type": "string",
                                "Description": "URL the Icon if available.",
                                "Attributes": []
                            },
                            "crossSaveOverride": {
                                "Name": "crossSaveOverride",
                                "Type": "int32",
                                "Description": "If there is a cross save override in effect, this value will tell you the type that is overridding this one.",
                                "Attributes": []
                            },
                            "applicableMembershipTypes": {
                                "Name": "applicableMembershipTypes",
                                "Type": "array",
                                "Description": "The list of Membership Types indicating the platforms on which this Membership can be used. Not in Cross Save = its original membership type. Cross Save Primary = Any membership types it is overridding, and its original membership type Cross Save Overridden = Empty list",
                                "Attributes": [],
                                "Array Contents": "int32"
                            },
                            "isPublic": {
                                "Name": "isPublic",
                                "Type": "boolean",
                                "Description": "If True, this is a public user membership.",
                                "Attributes": []
                            },
                            "membershipType": {
                                "Name": "membershipType",
                                "Type": "int32",
                                "Description": "Type of the membership. Not necessarily the native type.",
                                "Attributes": []
                            },
                            "membershipId": {
                                "Name": "membershipId",
                                "Type": "int64",
                                "Description": "Membership ID as they user is known in the Accounts service",
                                "Attributes": []
                            },
                            "displayName": {
                                "Name": "displayName",
                                "Type": "string",
                                "Description": "Display Name the player has chosen for themselves. The display name is optional when the data type is used as input to a platform API.",
                                "Attributes": []
                            },
                            "bungieGlobalDisplayName": {
                                "Name": "bungieGlobalDisplayName",
                                "Type": "string",
                                "Description": "The bungie global display name, if set.",
                                "Attributes": []
                            },
                            "bungieGlobalDisplayNameCode": {
                                "Name": "bungieGlobalDisplayNameCode",
                                "Type": "int16",
                                "Description": "The bungie global display name code, if set.",
                                "Attributes": [
                                    "Nullable"
                                ]
                            }
                        }
                    },
                    {
                        "bungieNetUserInfo": {
                            "supplementalDisplayName": {
                                "Name": "supplementalDisplayName",
                                "Type": "string",
                                "Description": "A platform specific additional display name - ex: psn Real Name, bnet Unique Name, etc.",
                                "Attributes": []
                            },
                            "iconPath": {
                                "Name": "iconPath",
                                "Type": "string",
                                "Description": "URL the Icon if available.",
                                "Attributes": []
                            },
                            "crossSaveOverride": {
                                "Name": "crossSaveOverride",
                                "Type": "int32",
                                "Description": "If there is a cross save override in effect, this value will tell you the type that is overridding this one.",
                                "Attributes": []
                            },
                            "applicableMembershipTypes": {
                                "Name": "applicableMembershipTypes",
                                "Type": "array",
                                "Description": "The list of Membership Types indicating the platforms on which this Membership can be used. Not in Cross Save = its original membership type. Cross Save Primary = Any membership types it is overridding, and its original membership type Cross Save Overridden = Empty list",
                                "Attributes": [],
                                "Array Contents": "int32"
                            },
                            "isPublic": {
                                "Name": "isPublic",
                                "Type": "boolean",
                                "Description": "If True, this is a public user membership.",
                                "Attributes": []
                            },
                            "membershipType": {
                                "Name": "membershipType",
                                "Type": "int32",
                                "Description": "Type of the membership. Not necessarily the native type.",
                                "Attributes": []
                            },
                            "membershipId": {
                                "Name": "membershipId",
                                "Type": "int64",
                                "Description": "Membership ID as they user is known in the Accounts service",
                                "Attributes": []
                            },
                            "displayName": {
                                "Name": "displayName",
                                "Type": "string",
                                "Description": "Display Name the player has chosen for themselves. The display name is optional when the data type is used as input to a platform API.",
                                "Attributes": []
                            },
                            "bungieGlobalDisplayName": {
                                "Name": "bungieGlobalDisplayName",
                                "Type": "string",
                                "Description": "The bungie global display name, if set.",
                                "Attributes": []
                            },
                            "bungieGlobalDisplayNameCode": {
                                "Name": "bungieGlobalDisplayNameCode",
                                "Type": "int16",
                                "Description": "The bungie global display name code, if set.",
                                "Attributes": [
                                    "Nullable"
                                ]
                            }
                        }
                    },
                    {
                        "characterId": {
                            "Name": "characterId",
                            "Type": "int64",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "dateJoined": {
                            "Name": "dateJoined",
                            "Type": "date-time",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "hasMicrophone": {
                            "Name": "hasMicrophone",
                            "Type": "boolean",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "lastPlatformInviteAttemptDate": {
                            "Name": "lastPlatformInviteAttemptDate",
                            "Type": "date-time",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "lastPlatformInviteAttemptResult": {
                            "Name": "lastPlatformInviteAttemptResult",
                            "Type": "byte",
                            "Description": "",
                            "Attributes": []
                        }
                    }
                ]
            },
            "Alternates": {
                "Name": "Alternates",
                "Type": "array",
                "Description": "",
                "Attributes": [],
                "Array Contents": [
                    {
                        "destinyUserInfo": {
                            "FireteamDisplayName": {
                                "Name": "FireteamDisplayName",
                                "Type": "string",
                                "Description": "",
                                "Attributes": []
                            },
                            "FireteamMembershipType": {
                                "Name": "FireteamMembershipType",
                                "Type": "int32",
                                "Description": "",
                                "Attributes": []
                            },
                            "supplementalDisplayName": {
                                "Name": "supplementalDisplayName",
                                "Type": "string",
                                "Description": "A platform specific additional display name - ex: psn Real Name, bnet Unique Name, etc.",
                                "Attributes": []
                            },
                            "iconPath": {
                                "Name": "iconPath",
                                "Type": "string",
                                "Description": "URL the Icon if available.",
                                "Attributes": []
                            },
                            "crossSaveOverride": {
                                "Name": "crossSaveOverride",
                                "Type": "int32",
                                "Description": "If there is a cross save override in effect, this value will tell you the type that is overridding this one.",
                                "Attributes": []
                            },
                            "applicableMembershipTypes": {
                                "Name": "applicableMembershipTypes",
                                "Type": "array",
                                "Description": "The list of Membership Types indicating the platforms on which this Membership can be used. Not in Cross Save = its original membership type. Cross Save Primary = Any membership types it is overridding, and its original membership type Cross Save Overridden = Empty list",
                                "Attributes": [],
                                "Array Contents": "int32"
                            },
                            "isPublic": {
                                "Name": "isPublic",
                                "Type": "boolean",
                                "Description": "If True, this is a public user membership.",
                                "Attributes": []
                            },
                            "membershipType": {
                                "Name": "membershipType",
                                "Type": "int32",
                                "Description": "Type of the membership. Not necessarily the native type.",
                                "Attributes": []
                            },
                            "membershipId": {
                                "Name": "membershipId",
                                "Type": "int64",
                                "Description": "Membership ID as they user is known in the Accounts service",
                                "Attributes": []
                            },
                            "displayName": {
                                "Name": "displayName",
                                "Type": "string",
                                "Description": "Display Name the player has chosen for themselves. The display name is optional when the data type is used as input to a platform API.",
                                "Attributes": []
                            },
                            "bungieGlobalDisplayName": {
                                "Name": "bungieGlobalDisplayName",
                                "Type": "string",
                                "Description": "The bungie global display name, if set.",
                                "Attributes": []
                            },
                            "bungieGlobalDisplayNameCode": {
                                "Name": "bungieGlobalDisplayNameCode",
                                "Type": "int16",
                                "Description": "The bungie global display name code, if set.",
                                "Attributes": [
                                    "Nullable"
                                ]
                            }
                        }
                    },
                    {
                        "bungieNetUserInfo": {
                            "supplementalDisplayName": {
                                "Name": "supplementalDisplayName",
                                "Type": "string",
                                "Description": "A platform specific additional display name - ex: psn Real Name, bnet Unique Name, etc.",
                                "Attributes": []
                            },
                            "iconPath": {
                                "Name": "iconPath",
                                "Type": "string",
                                "Description": "URL the Icon if available.",
                                "Attributes": []
                            },
                            "crossSaveOverride": {
                                "Name": "crossSaveOverride",
                                "Type": "int32",
                                "Description": "If there is a cross save override in effect, this value will tell you the type that is overridding this one.",
                                "Attributes": []
                            },
                            "applicableMembershipTypes": {
                                "Name": "applicableMembershipTypes",
                                "Type": "array",
                                "Description": "The list of Membership Types indicating the platforms on which this Membership can be used. Not in Cross Save = its original membership type. Cross Save Primary = Any membership types it is overridding, and its original membership type Cross Save Overridden = Empty list",
                                "Attributes": [],
                                "Array Contents": "int32"
                            },
                            "isPublic": {
                                "Name": "isPublic",
                                "Type": "boolean",
                                "Description": "If True, this is a public user membership.",
                                "Attributes": []
                            },
                            "membershipType": {
                                "Name": "membershipType",
                                "Type": "int32",
                                "Description": "Type of the membership. Not necessarily the native type.",
                                "Attributes": []
                            },
                            "membershipId": {
                                "Name": "membershipId",
                                "Type": "int64",
                                "Description": "Membership ID as they user is known in the Accounts service",
                                "Attributes": []
                            },
                            "displayName": {
                                "Name": "displayName",
                                "Type": "string",
                                "Description": "Display Name the player has chosen for themselves. The display name is optional when the data type is used as input to a platform API.",
                                "Attributes": []
                            },
                            "bungieGlobalDisplayName": {
                                "Name": "bungieGlobalDisplayName",
                                "Type": "string",
                                "Description": "The bungie global display name, if set.",
                                "Attributes": []
                            },
                            "bungieGlobalDisplayNameCode": {
                                "Name": "bungieGlobalDisplayNameCode",
                                "Type": "int16",
                                "Description": "The bungie global display name code, if set.",
                                "Attributes": [
                                    "Nullable"
                                ]
                            }
                        }
                    },
                    {
                        "characterId": {
                            "Name": "characterId",
                            "Type": "int64",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "dateJoined": {
                            "Name": "dateJoined",
                            "Type": "date-time",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "hasMicrophone": {
                            "Name": "hasMicrophone",
                            "Type": "boolean",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "lastPlatformInviteAttemptDate": {
                            "Name": "lastPlatformInviteAttemptDate",
                            "Type": "date-time",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "lastPlatformInviteAttemptResult": {
                            "Name": "lastPlatformInviteAttemptResult",
                            "Type": "byte",
                            "Description": "",
                            "Attributes": []
                        }
                    }
                ]
            }
        }


        .. seealso:: https://bungie-net.github.io/multi/operation_get_Fireteam-GetClanFireteam.html#operation_get_Fireteam-GetClanFireteam"""

        try:
            self.logger.info("Executing GetClanFireteam...")
            url = (
                self.base_url
                + f"/Fireteam/Clan/{groupId}/Summary/{fireteamId}/".format(
                    fireteamId=fireteamId, groupId=groupId
                )
            )
            return await self.requester.request(
                method=HTTPMethod.GET, url=url, access_token=access_token
            )
        except Exception as ex:
            self.logger.exception(ex)



from destipy.utils.requester import Requester


class Base:
    """Base endpoints."""

    def __init__(self, requester, logger):
        self.requester: Requester = requester
        self.logger = logger
        self.base_url = "https://www.bungie.net/Platform"



from datetime import datetime
from destipy.utils.http_method import HTTPMethod
from destipy.utils.requester import Requester


class App:
    """App endpoints."""

    def __init__(self, requester, logger):
        self.requester: Requester = requester
        self.logger = logger
        self.base_url = "https://www.bungie.net/Platform"

    async def GetApplicationApiUsage(
        self, applicationId: int, end: datetime, start: datetime, access_token: str
    ) -> dict:
        """Get API usage by application for time frame specified. You can go as far back as 30 days ago, and can ask for up to a 48 hour window of time in a single request. You must be authenticated with at least the ReadUserData permission to access this endpoint.

            Args:
                applicationId (int): ID of the application to get usage statistics.
                end (datetime): End time for query. Goes to now if not specified.
                start (datetime): Start time for query. Goes to 24 hours ago if not specified.
                access_token (str): OAuth token

            Returns:
        {
            "apiCalls": {
                "Name": "apiCalls",
                "Type": "array",
                "Description": "Counts for on API calls made for the time range.",
                "Attributes": [],
                "Array Contents": [
                    {
                        "datapoints": {
                            "Name": "datapoints",
                            "Type": "array",
                            "Description": "Collection of samples with time and value.",
                            "Attributes": []
                        }
                    },
                    {
                        "target": {
                            "Name": "target",
                            "Type": "string",
                            "Description": "Target to which to datapoints apply.",
                            "Attributes": []
                        }
                    }
                ]
            },
            "throttledRequests": {
                "Name": "throttledRequests",
                "Type": "array",
                "Description": "Instances of blocked requests or requests that crossed the warn threshold during the time range.",
                "Attributes": [],
                "Array Contents": [
                    {
                        "datapoints": {
                            "Name": "datapoints",
                            "Type": "array",
                            "Description": "Collection of samples with time and value.",
                            "Attributes": []
                        }
                    },
                    {
                        "target": {
                            "Name": "target",
                            "Type": "string",
                            "Description": "Target to which to datapoints apply.",
                            "Attributes": []
                        }
                    }
                ]
            }
        }


        .. seealso:: https://bungie-net.github.io/multi/operation_get_App-GetApplicationApiUsage.html#operation_get_App-GetApplicationApiUsage"""

        try:
            self.logger.info("Executing GetApplicationApiUsage...")
            url = self.base_url + f"/App/ApiUsage/{applicationId}/".format(
                applicationId=applicationId, end=end, start=start
            )
            return await self.requester.request(
                method=HTTPMethod.GET, url=url, access_token=access_token
            )
        except Exception as ex:
            self.logger.exception(ex)

    async def GetBungieApplications(self) -> dict:
        """Get list of applications created by Bungie.

            Args:

            Returns:
        {
            "applicationId": {
                "Name": "applicationId",
                "Type": "int32",
                "Description": "Unique ID assigned to the application",
                "Attributes": []
            },
            "name": {
                "Name": "name",
                "Type": "string",
                "Description": "Name of the application",
                "Attributes": []
            },
            "redirectUrl": {
                "Name": "redirectUrl",
                "Type": "string",
                "Description": "URL used to pass the user's authorization code to the application",
                "Attributes": []
            },
            "link": {
                "Name": "link",
                "Type": "string",
                "Description": "Link to website for the application where a user can learn more about the app.",
                "Attributes": []
            },
            "scope": {
                "Name": "scope",
                "Type": "int64",
                "Description": "Permissions the application needs to work",
                "Attributes": []
            },
            "origin": {
                "Name": "origin",
                "Type": "string",
                "Description": "Value of the Origin header sent in requests generated by this application.",
                "Attributes": []
            },
            "status": {
                "Name": "status",
                "Type": "int32",
                "Description": "Current status of the application.",
                "Attributes": []
            },
            "creationDate": {
                "Name": "creationDate",
                "Type": "date-time",
                "Description": "Date the application was first added to our database.",
                "Attributes": []
            },
            "statusChanged": {
                "Name": "statusChanged",
                "Type": "date-time",
                "Description": "Date the application status last changed.",
                "Attributes": []
            },
            "firstPublished": {
                "Name": "firstPublished",
                "Type": "date-time",
                "Description": "Date the first time the application status entered the 'Public' status.",
                "Attributes": []
            },
            "team": {
                "Name": "team",
                "Type": "array",
                "Description": "List of team members who manage this application on Bungie.net. Will always consist of at least the application owner.",
                "Attributes": [],
                "Array Contents": [
                    {
                        "role": {
                            "Name": "role",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "apiEulaVersion": {
                            "Name": "apiEulaVersion",
                            "Type": "int32",
                            "Description": "",
                            "Attributes": []
                        }
                    },
                    {
                        "user": {
                            "supplementalDisplayName": {
                                "Name": "supplementalDisplayName",
                                "Type": "string",
                                "Description": "A platform specific additional display name - ex: psn Real Name, bnet Unique Name, etc.",
                                "Attributes": []
                            },
                            "iconPath": {
                                "Name": "iconPath",
                                "Type": "string",
                                "Description": "URL the Icon if available.",
                                "Attributes": []
                            },
                            "crossSaveOverride": {
                                "Name": "crossSaveOverride",
                                "Type": "int32",
                                "Description": "If there is a cross save override in effect, this value will tell you the type that is overridding this one.",
                                "Attributes": []
                            },
                            "applicableMembershipTypes": {
                                "Name": "applicableMembershipTypes",
                                "Type": "array",
                                "Description": "The list of Membership Types indicating the platforms on which this Membership can be used. Not in Cross Save = its original membership type. Cross Save Primary = Any membership types it is overridding, and its original membership type Cross Save Overridden = Empty list",
                                "Attributes": [],
                                "Array Contents": "int32"
                            },
                            "isPublic": {
                                "Name": "isPublic",
                                "Type": "boolean",
                                "Description": "If True, this is a public user membership.",
                                "Attributes": []
                            },
                            "membershipType": {
                                "Name": "membershipType",
                                "Type": "int32",
                                "Description": "Type of the membership. Not necessarily the native type.",
                                "Attributes": []
                            },
                            "membershipId": {
                                "Name": "membershipId",
                                "Type": "int64",
                                "Description": "Membership ID as they user is known in the Accounts service",
                                "Attributes": []
                            },
                            "displayName": {
                                "Name": "displayName",
                                "Type": "string",
                                "Description": "Display Name the player has chosen for themselves. The display name is optional when the data type is used as input to a platform API.",
                                "Attributes": []
                            },
                            "bungieGlobalDisplayName": {
                                "Name": "bungieGlobalDisplayName",
                                "Type": "string",
                                "Description": "The bungie global display name, if set.",
                                "Attributes": []
                            },
                            "bungieGlobalDisplayNameCode": {
                                "Name": "bungieGlobalDisplayNameCode",
                                "Type": "int16",
                                "Description": "The bungie global display name code, if set.",
                                "Attributes": [
                                    "Nullable"
                                ]
                            }
                        }
                    }
                ]
            },
            "overrideAuthorizeViewName": {
                "Name": "overrideAuthorizeViewName",
                "Type": "string",
                "Description": "An optional override for the Authorize view name.",
                "Attributes": []
            }
        }


        .. seealso:: https://bungie-net.github.io/multi/operation_get_App-GetBungieApplications.html#operation_get_App-GetBungieApplications"""

        try:
            self.logger.info("Executing GetBungieApplications...")
            url = self.base_url + "/App/FirstParty/".format()
            return await self.requester.request(method=HTTPMethod.GET, url=url)
        except Exception as ex:
            self.logger.exception(ex)
